@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.lb.logger/src/logd_proto.c,v 1.32 2012/03/22 12:41:06 mvocu Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -319,18 +319,20 @@ int wait_for_confirmation(struct timeval *timeout, int *code)
 int do_listen(int port)
 {
 	int                ret;
-	int                sock;
+	int                sock = -1;
 	char 		*portstr = NULL;
 
 	asprintf(&portstr, "%d", port);
 	if (portstr == NULL) {
 		glite_common_log(LOG_CATEGORY_CONTROL,LOG_PRIORITY_FATAL,"do_listen(): ENOMEM converting port number\n");
-		return -1;
+		goto err;
 	}
 
 	if (daemon_listen(NULL, portstr, &sock) != 0)
-		return -1;
+		goto err;
 
+err:
+	free(portstr);
 	return sock;
 }
 
